quantizationtools.QEventProxy
=============================

.. abjad-lineage:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy

.. autoclass:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.index
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.q_event
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventProxy.QEventProxy.QEventProxy.__setstate__
   :noindex:
